use crate::config::Context;
use crate::ip::IpData;
use crate::utils::sleep_s;

use reqwest::Error as ReqError;

pub async fn send_to_ipbl_ws(ctx: &Context, ip: &IpData, ret: &mut Vec<String>) {
    ret.push(format!("host: {hostname}", hostname = ctx.hostname));
    loop {
        match push_ip(&ctx, &ip, ret).await {
            Ok(_) => {
                break;
            }
            Err(err) => {
                println!("{err}");
                sleep_s(1).await;
            }
        };
    }
}

async fn push_ip(ctx: &Context, ip: &IpData, ret: &mut Vec<String>) -> Result<(), ReqError> {
    let result: String;
    let mut data: Vec<IpData> = vec![];

    data.push(IpData {
        ip: ip.ip.to_string(),
        src: ip.src.to_string(),
        date: ip.date.to_string(),
        hostname: ip.hostname.to_string(),
        mode: "file".to_string(),
    });

    let resp = ctx
        .client
        .post(format!("{server}/ips", server = ctx.flags.server))
        .json(&data)
        .send()
        .await?;
    ret.push(format!("status: {status}", status = resp.status()));

    let res = resp.text().await.unwrap();

    if res.trim().len() > 0 {
        result = res.trim().to_string();
    } else {
        result = "".to_string();
    }

    ret.push(format!("response: {result}"));
    Ok(())
}

async fn _push_ip_bulk(
    ctx: &Context,
    ips: &Vec<IpData>,
    ret: &mut Vec<String>,
) -> Result<(), ReqError> {
    let result: String;
    let mut data: Vec<IpData> = vec![];

    for ip in ips {
        data.push(IpData {
            ip: ip.ip.to_string(),
            src: ip.src.to_string(),
            date: ip.date.to_string(),
            hostname: ip.hostname.to_string(),
            mode: "file".to_string(),
        })
    }

    let resp = ctx
        .client
        .post(format!("{server}/ips", server = ctx.flags.server))
        .json(&data)
        .send()
        .await?;
    ret.push(format!("status: {status}", status = resp.status()));

    let res = resp.text().await.unwrap();

    if res.trim().len() > 0 {
        result = res.trim().to_string();
    } else {
        result = "".to_string();
    }

    ret.push(format!("response: {result}"));
    Ok(())
}
